@@ -26,6 +26,7 @@
 #include "archivefactory.h"
 
 #include <QFile>
+#include <QFileInfo>
 
 #include <KDebug>
 #include <KMimeType>
@@ -64,6 +65,12 @@ namespace Kerfuffle
 		{
 			QString libraryName = offers[ 0 ]->library();
 			KLibrary *lib = KLibLoader::self()->library( QFile::encodeName( libraryName ), QLibrary::ExportExternalSymbolsHint );
+			//TODO: get rid of the deprecated klibloader::self
+#if 0
+			
+			KPluginLoader loader(offers.at(0));
+			KPluginFactory *factory = loader.factory();
+#endif
 
 			kDebug( 1601 ) << "Loading library " << libraryName ;
 			if ( lib )
@@ -72,7 +79,7 @@ namespace Kerfuffle
 				if ( pluginFactory )
 				{
 					ArchiveFactory *factory = pluginFactory(); // TODO: cache these
-					Archive *arch = factory->createArchive( filename, 0 );
+					Archive *arch = factory->createArchive( QFileInfo(filename).absoluteFilePath(), 0 );
 					delete factory;
 					return arch;
 				}
