@@ -35,35 +35,36 @@
 #include "kgpgsettings.h"
 #include "kgpginterface.h"
 #include "kgpgtextinterface.h"
+#include "kgpgitemmodel.h"
 
 using namespace KgpgCore;
 
-KgpgLibrary::KgpgLibrary(QWidget *parent, const bool &pgpExtension)
+KgpgLibrary::KgpgLibrary(QWidget *parent)
 {
-    if (pgpExtension)
-        m_extension = ".pgp";
-    else
-        m_extension = ".gpg";
+    m_extension = ".gpg";
 
     m_popisactive = false;
     m_panel = parent;
 }
 
-void KgpgLibrary::slotFileEnc(const KUrl::List &urls, const QStringList &opts, const QStringList &defaultKey, const KShortcut &goDefaultKey)
+void KgpgLibrary::setFileExtension(const QString &ext)
+{
+    m_extension = ext;
+}
+
+void KgpgLibrary::slotFileEnc(const KUrl::List &urls, const QStringList &opts, KGpgItemModel *model, const KShortcut &goDefaultKey, const QString &defaultKey)
 {
     if (!urls.empty())
     {
         m_urlselecteds = urls;
-        if (defaultKey.isEmpty())
-        {
             QString fileNames = urls.first().fileName();
             if (urls.count() > 1)
-                fileNames += ",...";
+                fileNames += ", ...";
 
-            KgpgSelectPublicKeyDlg *dialog = new KgpgSelectPublicKeyDlg(0, fileNames, goDefaultKey);
+            KgpgSelectPublicKeyDlg *dialog = new KgpgSelectPublicKeyDlg(0, model, goDefaultKey, fileNames);
             if (dialog->exec() == KDialog::Accepted)
             {
-                QStringList options;
+                QStringList options = opts;
                 if (dialog->getUntrusted()) options << "--always-trust";
                 if (dialog->getArmor())     options << "--armor";
                 if (dialog->getHideId())    options << "--throw-keyid";
@@ -72,13 +73,13 @@ void KgpgLibrary::slotFileEnc(const KUrl::List &urls, const QStringList &opts, c
                     if (KGpgSettings::allowCustomEncryptionOptions())
                         options << dialog->getCustomOptions().split(' ');
 
-                startEncode(dialog->selectedKeys(), options, dialog->getSymmetric());
+                QStringList keys = dialog->selectedKeys();
+                if (!defaultKey.isEmpty() && !keys.contains(defaultKey))
+                    keys << defaultKey;
+                startEncode(keys, options, dialog->getSymmetric());
             }
 
             delete dialog;
-        }
-        else
-            startEncode(defaultKey, opts, false);
     }
 }
 
@@ -187,45 +188,10 @@ void KgpgLibrary::processDecOver(int ret, KGpgTextInterface *iface)
 	emit decryptionOver(this, KUrl());
 }
 
-void KgpgLibrary::processDecError(const QString &mssge)
+void KgpgLibrary::slotImportOver(KgpgInterface *iface, const QStringList &keys)
 {
-    delete m_pop;
-    emit systemMessage(QString());
-
-    // test if file is a public key
-    QFile qfile(QFile::encodeName(m_urlselected.path()));
-    if (qfile.open(QIODevice::ReadOnly))
-    {
-        QTextStream t(&qfile);
-        QString result = t.readAll();
-        qfile.close();
-
-        // if pgp data found, decode it
-        if (result.startsWith("-----BEGIN PGP PUBLIC KEY BLOCK"))
-        {
-            // dropped file is a public key, ask for import
-            int result = KMessageBox::warningContinueCancel(0, i18n("<p>The file <b>%1</b> is a public key.<br />Do you want to import it ?</p>", m_urlselected.path()));
-            if (result == KMessageBox::Cancel)
-                return;
-            else
-            {
-                KgpgInterface *importKeyProcess = new KgpgInterface();
-                importKeyProcess->importKey(m_urlselected);
-                connect(importKeyProcess, SIGNAL(importfinished(QStringList)), this, SIGNAL(importOver(QStringList)));
-                return;
-            }
-        }
-        else
-        if(result.startsWith("-----BEGIN PGP PRIVATE KEY BLOCK"))
-        {
-            // dropped file is a public key, ask for import
-            qfile.close();
-            KMessageBox::information(0, i18n("<p>The file <b>%1</b> is a private key block. Please use KGpg key manager to import it.</p>", m_urlselected.path()));
-            return;
-        }
-    }
-
-    KMessageBox::detailedSorry(0, i18n("Decryption failed."), mssge);
+    iface->deleteLater();
+    emit importOver(this, keys);
 }
 
 void KgpgLibrary::processEncPopup(const KUrl &url)
@@ -253,32 +219,4 @@ void KgpgLibrary::processPopup2(const QString &fileName)
     m_pop->move(iXpos,iYpos);*/
 }
 
-void KgpgLibrary::addPhoto(const QString &keyid)
-{
-    QString mess = i18n("The image must be a JPEG file. Remember that the image is stored within your public key."
-                        "If you use a very large picture, your key will become very large as well! Keeping the image "
-                        "close to 240x288 is a good size to use.");
-
-    if (KMessageBox::warningContinueCancel(0, mess) != KMessageBox::Continue)
-        return;
-
-    QString imagepath = KFileDialog::getOpenFileName(KUrl(), "image/jpeg", 0);
-    if (imagepath.isEmpty())
-        return;
-
-    KgpgInterface *interface = new KgpgInterface();
-    connect(interface, SIGNAL(addPhotoFinished(int, KgpgInterface*)), this, SLOT(slotAddPhotoFinished(int, KgpgInterface*)));
-    interface->addPhoto(keyid, imagepath);
-}
-
-void KgpgLibrary::slotAddPhotoFinished(int res, KgpgInterface *interface)
-{
-    interface->deleteLater();
-
-    // TODO : add res == 3 (bad passphrase)
-
-    if (res == 2)
-        emit photoAdded();
-}
-
 #include "kgpglibrary.moc"
