@@ -20,46 +20,53 @@
 
 #include "allyourbase.h"
 
-#include <kapplication.h>
 #include <kdebug.h>
+#include <kcomponentdata.h>
 #include <kglobal.h>
 #include <kio/netaccess.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kstandarddirs.h>
 #include <kurl.h>
-#include <kurldrag.h>
+#include <k3urldrag.h>
 #include <kwallet.h>
 
-#include <qdragobject.h>
-#include <qfile.h>
-#include <qptrlist.h>
+#include <Q3DragObject>
+#include <QFile>
+#include <QApplication>
+#include <Q3PtrList>
+//Added by qt3to4:
+#include <QPixmap>
+#include <Q3StrList>
+#include <QDropEvent>
+#include <QDragEnterEvent>
+#include <QMouseEvent>
 
 /****************
  *  KWalletFolderItem - ListView items to represent kwallet folders
  */
-KWalletFolderItem::KWalletFolderItem(KWallet::Wallet *w, QListView* parent, const QString &name, int entries)
-: KListViewItem(parent),_wallet(w),_name(name),_entries(entries) {
+KWalletFolderItem::KWalletFolderItem(KWallet::Wallet *w, Q3ListView* parent, const QString &name, int entries)
+: K3ListViewItem(parent),_wallet(w),_name(name),_entries(entries) {
 	setText(0, QString("%1 (%2)").arg(_name).arg(_entries));
 	setRenameEnabled(0, false);
 	setDragEnabled(true);
 	setDropEnabled(true);
 
-	QPixmap pix = getFolderIcon(KIcon::Small);
+	QPixmap pix = getFolderIcon(KIconLoader::Small);
 	
 	setPixmap(0,pix);
 }
 
-QPixmap KWalletFolderItem::getFolderIcon(KIcon::Group group){
-	KIconLoader *loader = KGlobal::instance()->iconLoader();
+QPixmap KWalletFolderItem::getFolderIcon(KIconLoader::Group group){
+	KIconLoader *loader = KIconLoader::global();
 	QPixmap pix = loader->loadIcon( _name, group, 0,
-			KIcon::DefaultState, 0, true );
+			KIconLoader::DefaultState, QStringList(),0, true );
 	if (pix.isNull())
-		pix = loader->loadIcon( _name.lower(), group, 0,
-			KIcon::DefaultState, 0, true);
+		pix = loader->loadIcon( _name.toLower(), group, 0,
+			KIconLoader::DefaultState, QStringList(),0, true);
 	if (pix.isNull())
-		pix = loader->loadIcon( "folder_red", group, 0,
-			KIcon::DefaultState, 0, true);
+		pix = loader->loadIcon( "folder-red", group, 0,
+			KIconLoader::DefaultState, QStringList(),0, true);
 	return pix;
 }
 
@@ -71,7 +78,7 @@ void KWalletFolderItem::refresh() {
 }
 
 KWalletContainerItem* KWalletFolderItem::getContainer(KWallet::Wallet::EntryType type) {
-	for (QListViewItem *i = firstChild(); i; i = i->nextSibling()) {
+	for (Q3ListViewItem *i = firstChild(); i; i = i->nextSibling()) {
 		KWalletContainerItem *ci = dynamic_cast<KWalletContainerItem *>(i);
 		if (!ci) {
 			continue;
@@ -87,13 +94,13 @@ bool KWalletFolderItem::contains(const QString& key) {
 	return (getItem(key) != 0);
 }
 
-QListViewItem* KWalletFolderItem::getItem(const QString& key) {
-	for (QListViewItem *i = firstChild(); i; i = i->nextSibling()) {
+Q3ListViewItem* KWalletFolderItem::getItem(const QString& key) {
+	for (Q3ListViewItem *i = firstChild(); i; i = i->nextSibling()) {
 		KWalletContainerItem *ci = dynamic_cast<KWalletContainerItem *>(i);
 		if (!ci) {
 			continue;
 		}
-		QListViewItem *tmp = ci->getItem(key);
+		Q3ListViewItem *tmp = ci->getItem(key);
 		if (tmp) {
 			return tmp;
 		}
@@ -121,8 +128,8 @@ KWalletFolderItem::~KWalletFolderItem() {
  *  KWalletContainerItem - ListView items to represent kwallet containers, i.e.
  *  passwords, maps, ...
  */
-KWalletContainerItem::KWalletContainerItem(QListViewItem* parent, const QString &name, KWallet::Wallet::EntryType type)
-: KListViewItem(parent, name), _type(type) {
+KWalletContainerItem::KWalletContainerItem(Q3ListViewItem* parent, const QString &name, KWallet::Wallet::EntryType type)
+: K3ListViewItem(parent, name), _type(type) {
 	setRenameEnabled(0, false);
 	setDragEnabled(true);
 }
@@ -142,8 +149,8 @@ bool KWalletContainerItem::contains(const QString& key) {
 	return getItem(key) != 0;
 }
 
-QListViewItem *KWalletContainerItem::getItem(const QString& key) {
-	for (QListViewItem *i = firstChild(); i; i = i->nextSibling()) {
+Q3ListViewItem *KWalletContainerItem::getItem(const QString& key) {
+	for (Q3ListViewItem *i = firstChild(); i; i = i->nextSibling()) {
 		if (i->text(0) == key) {
 			return i;
 		}
@@ -154,8 +161,8 @@ QListViewItem *KWalletContainerItem::getItem(const QString& key) {
 /****************
  *  KWalletEntryItem - ListView items to represent kwallet entries
  */
-KWalletEntryItem::KWalletEntryItem(KWallet::Wallet *w, QListViewItem* parent, const QString& ename)
-: KListViewItem(parent, ename), _wallet(w), _oldName(ename) {
+KWalletEntryItem::KWalletEntryItem(KWallet::Wallet *w, Q3ListViewItem* parent, const QString& ename)
+: K3ListViewItem(parent, ename), _wallet(w), _oldName(ename) {
 	setRenameEnabled(0, true);
 	setDragEnabled(true);
 }
@@ -170,8 +177,8 @@ KWalletEntryItem::~KWalletEntryItem() {
 /****************
  * KWalletItem - IconView items to represent wallets
  */
-KWalletItem::KWalletItem(QIconView *parent, const QString& walletName)
-: QIconViewItem(parent, walletName, DesktopIcon("kwalletmanager")) {
+KWalletItem::KWalletItem(Q3IconView *parent, const QString& walletName)
+: Q3IconViewItem(parent, walletName, DesktopIcon("wallet-closed")), _open(false) {
 }
 
 KWalletItem::~KWalletItem() {
@@ -182,11 +189,22 @@ bool KWalletItem::acceptDrop(const QMimeSource *mime) const {
 		mime->provides("text/uri-list");
 }
 
+void KWalletItem::setOpen(bool state) {
+	if (_open != state) {
+		_open = state;
+		if (_open) {
+			setPixmap( DesktopIcon("wallet-open") );
+		} else {
+			setPixmap( DesktopIcon("wallet-closed") );
+		}
+	}
+}
+
 static bool decodeEntry(KWallet::Wallet *_wallet, QDataStream& ds) {
-	Q_UINT32 magic;
+	quint32 magic;
 	ds >> magic;
 	if (magic != KWALLETENTRYMAGIC) {
-		kdDebug() << "bad magic" << endl;
+		kDebug() << "bad magic" ;
 		return false;
 	}
 	QString name;
@@ -194,12 +212,12 @@ static bool decodeEntry(KWallet::Wallet *_wallet, QDataStream& ds) {
 	KWallet::Wallet::EntryType et;
 	ds >> name;
 	if (_wallet->hasEntry(name)) {
-		int rc = KMessageBox::warningContinueCancel(0L, i18n("An entry by the name '%1' already exists. Would you like to continue?").arg(name));
+		int rc = KMessageBox::warningContinueCancel(0L, i18n("An entry by the name '%1' already exists. Would you like to continue?", name));
 		if (rc == KMessageBox::Cancel) {
 			return false;
 		}
 	}
-	long l;
+	qint32 l;
 	ds >> l;
 	et = KWallet::Wallet::EntryType(l);
 	ds >> value;
@@ -208,16 +226,16 @@ static bool decodeEntry(KWallet::Wallet *_wallet, QDataStream& ds) {
 }
 
 static bool decodeFolder(KWallet::Wallet *_wallet, QDataStream& ds) {
-	Q_UINT32 magic;
+	quint32 magic;
 	ds >> magic;
 	if (magic != KWALLETFOLDERMAGIC) {
-		kdDebug() << "bad magic" << endl;
+		kDebug() << "bad magic" ;
 		return false;
 	}
 	QString folder;
 	ds >> folder;
 	if (_wallet->hasFolder(folder)) {
-		int rc = KMessageBox::warningYesNoCancel(0L, i18n("A folder by the name '%1' already exists.  What would you like to do?").arg(folder), QString::null, KStdGuiItem::cont(), i18n("Replace"));
+		int rc = KMessageBox::warningYesNoCancel(0L, i18n("A folder by the name '%1' already exists.  What would you like to do?", folder), QString(), KStandardGuiItem::cont(), KGuiItem(i18n("Replace")));
 		if (rc == KMessageBox::Cancel) {
 			return false;
 		}
@@ -235,7 +253,7 @@ static bool decodeFolder(KWallet::Wallet *_wallet, QDataStream& ds) {
 		QByteArray value;
 		KWallet::Wallet::EntryType et;
 		ds >> name;
-		long l;
+		qint32 l;
 		ds >> l;
 		et = KWallet::Wallet::EntryType(l);
 		ds >> value;
@@ -244,14 +262,14 @@ static bool decodeFolder(KWallet::Wallet *_wallet, QDataStream& ds) {
 	return true;
 }
 
-void KWalletItem::dropped(QDropEvent *e, const QValueList<QIconDragItem>& lst) {
+void KWalletItem::dropped(QDropEvent *e, const Q3ValueList<Q3IconDragItem>& lst) {
 	Q_UNUSED(lst);
 	if (e->provides("application/x-kwallet-folder") || 
 			e->provides("text/uri-list")) {
 
 		// FIXME: don't allow the drop if the wallet name is the same
 
-		KWallet::Wallet *_wallet = KWallet::Wallet::openWallet(text());
+		KWallet::Wallet *_wallet = KWallet::Wallet::openWallet(text(), iconView()->topLevelWidget()->winId());
 		if (!_wallet) {
 			e->ignore();
 			return;
@@ -265,26 +283,26 @@ void KWalletItem::dropped(QDropEvent *e, const QValueList<QIconDragItem>& lst) {
 		if (e->provides("application/x-kwallet-folder")) {
 			QByteArray edata = e->encodedData("application/x-kwallet-folder");
 			if (!edata.isEmpty()) {
-				ds = new QDataStream(edata, IO_ReadOnly);
+				ds = new QDataStream(&edata, QIODevice::ReadOnly);
 			}
 		} else { // text/uri-list
-			QStrList urls;
-			QUriDrag::decode(e, urls);
+			Q3StrList urls;
+			Q3UriDrag::decode(e, urls);
 
 			if (urls.isEmpty()) {
 				e->ignore();
 				return;
 			}
 
-			KURL u(urls.first());
+			KUrl u(urls.first());
 			if (u.fileName().isEmpty()) {
 				e->ignore();
 				return;
 			}
 			QString tmpFile;
 			if (KIO::NetAccess::download(u, tmpFile, 0L)) {
-				file.setName(tmpFile);
-				file.open(IO_ReadOnly);
+				file.setFileName(tmpFile);
+				file.open(QIODevice::ReadOnly);
 				ds = new QDataStream(&file);
 				KIO::NetAccess::removeTempFile(tmpFile);
 			} else {
@@ -299,10 +317,10 @@ void KWalletItem::dropped(QDropEvent *e, const QValueList<QIconDragItem>& lst) {
 		delete _wallet;
 
 		//delete the folder from the source if we were moving
-		Qt::ButtonState state = kapp->keyboardMouseState();
+		Qt::ButtonState state = QApplication::mouseButtons();
 		if (e->source() && e->source()->parent() &&
-			!strcmp(e->source()->parent()->className(), "KWalletEntryList") &&
-			!(state & Qt::ControlButton)) {
+		    !strcmp(e->source()->parent()->metaObject()->className(), "KWalletEntryList") &&
+			!(state & Qt::ControlModifier)) {
 		
 			KWalletEntryList *el =
 				dynamic_cast<KWalletEntryList*>(e->source()->parent());
@@ -324,10 +342,10 @@ void KWalletItem::dropped(QDropEvent *e, const QValueList<QIconDragItem>& lst) {
 /****************
  *  KWalletEntryDrag - Stores data for wallet entry drags
  */
-class KWalletEntryDrag : public QStoredDrag {
+class KWalletEntryDrag : public Q3StoredDrag {
 	public:
 		KWalletEntryDrag(QWidget *dragSource, const char *name = 0L)
-			: QStoredDrag("application/x-kwallet-entry", dragSource, name) {
+			: Q3StoredDrag("application/x-kwallet-entry", dragSource, name) {
 		}
 
 		virtual ~KWalletEntryDrag() {}
@@ -336,10 +354,10 @@ class KWalletEntryDrag : public QStoredDrag {
 /****************
  *  KWalletFolderDrag - Stores data for wallet folder drags
  */
-class KWalletFolderDrag : public QStoredDrag {
+class KWalletFolderDrag : public Q3StoredDrag {
 	public:
 		KWalletFolderDrag(QWidget *dragSource, const char *name = 0L)
-			: QStoredDrag("application/x-kwallet-folder", dragSource, name) {
+			: Q3StoredDrag("application/x-kwallet-folder", dragSource, name) {
 		}
 
 		virtual ~KWalletFolderDrag() {}
@@ -349,7 +367,8 @@ class KWalletFolderDrag : public QStoredDrag {
  *  KWalletEntryList - A listview to store wallet entries
  */
 KWalletEntryList::KWalletEntryList(QWidget *parent, const char *name)
-: KListView(parent, name) {
+: K3ListView(parent) {
+	setObjectName(name);
 	addColumn(i18n("Folders"));
 	setRootIsDecorated(true);
 	setDefaultRenameAction(Reject);
@@ -363,7 +382,7 @@ KWalletEntryList::~KWalletEntryList() {
 }
 
 bool KWalletEntryList::acceptDrag(QDropEvent* e) const {
-	QListViewItem *i = itemAt(contentsToViewport(e->pos()));
+	Q3ListViewItem *i = itemAt(contentsToViewport(e->pos()));
 	if (i) {
 		if (e->provides("application/x-kwallet-entry") ||
 				e->provides("text/uri-list")) {
@@ -379,19 +398,19 @@ bool KWalletEntryList::acceptDrag(QDropEvent* e) const {
 }
 
 //returns true if the item has been dropped successfully
-void KWalletEntryList::itemDropped(QDropEvent *e, QListViewItem *item) {
+void KWalletEntryList::itemDropped(QDropEvent *e, Q3ListViewItem *item) {
 	bool ok = true;
 	bool isEntry;
 	QFile file;
 	QDataStream *ds;
 
 	KWalletEntryList *el = 0L;
-	QListViewItem *sel = 0L;
+	Q3ListViewItem *sel = 0L;
 
 	//detect if we are dragging from kwallet itself
 	if (e->source() && e->source()->parent() &&
-		!strcmp(e->source()->parent()->className(), "KWalletEntryList")) {
-
+	    !strcmp(e->source()->parent()->metaObject()->className(), "KWalletEntryList")) {
+	  
 		el = dynamic_cast<KWalletEntryList*>(e->source()->parent());
 		if (!el) {
 			KMessageBox::error(this, i18n("An unexpected error occurred trying to drop the item"));
@@ -412,7 +431,7 @@ void KWalletEntryList::itemDropped(QDropEvent *e, QListViewItem *item) {
 			e->ignore();
 			return;
 		}
-		ds = new QDataStream(data, IO_ReadOnly);
+		ds = new QDataStream(&data, QIODevice::ReadOnly);
 	} else if (e->provides("application/x-kwallet-folder")) {
 		//do nothing if we are in the same wallet
 		if (this == el) {
@@ -425,37 +444,37 @@ void KWalletEntryList::itemDropped(QDropEvent *e, QListViewItem *item) {
 			e->ignore();
 			return;
 		}
-		ds = new QDataStream(data, IO_ReadOnly);
+		ds = new QDataStream(&data, QIODevice::ReadOnly);
 	} else if (e->provides("text/uri-list")) {
-		QStrList urls;
-		QUriDrag::decode(e, urls);
+		Q3StrList urls;
+		Q3UriDrag::decode(e, urls);
 		if (urls.isEmpty()) {
 			e->ignore();
 			return;
 		}
-		KURL u(urls.first());
+		KUrl u(urls.first());
 		if (u.fileName().isEmpty()) {
 			e->ignore();
 			return;
 		}
 		QString tmpFile;
 		if (KIO::NetAccess::download(u, tmpFile, 0L)) {
-			file.setName(tmpFile);
-			file.open(IO_ReadOnly);
+			file.setFileName(tmpFile);
+			file.open(QIODevice::ReadOnly);
 			ds = new QDataStream(&file);
 			//check magic to discover mime type
-			Q_UINT32 magic;
+			quint32 magic;
 			(*ds) >> magic;
+			delete ds;
 			if (magic == KWALLETENTRYMAGIC) {
 				isEntry = true;
 			} else if (magic == KWALLETFOLDERMAGIC) {
 				isEntry = false;
 			} else {
-				kdDebug() << "bad magic" << endl;
+				kDebug() << "bad magic" ;
 				e->ignore();
 				return;
 			}
-			delete ds;
 			//set the file back to the beginning
 			file.reset();
 			ds = new QDataStream(&file);
@@ -468,10 +487,11 @@ void KWalletEntryList::itemDropped(QDropEvent *e, QListViewItem *item) {
 		e->ignore();
 		return;
 	}
-	Qt::ButtonState state = kapp->keyboardMouseState();
+	Qt::ButtonState state = QApplication::mouseButtons();
 	if (isEntry) {
 		if (!item) {
 			e->ignore();
+			delete(ds);
 			return;
 		}
 		KWalletFolderItem *fi = KWalletEntryList::getItemFolder(item);
@@ -489,7 +509,7 @@ void KWalletEntryList::itemDropped(QDropEvent *e, QListViewItem *item) {
 		delete(ds);
 		//delete source if we were moving, i.e., we are dragging
 		//from kwalletmanager and Control is not pressed
-		if (ok && el && !(state & Qt::ControlButton) && sel) {
+		if (ok && el && !(state & Qt::ControlModifier) && sel) {
 			el->_wallet->removeEntry(sel->text(0));
 			delete sel;
 		}
@@ -499,7 +519,7 @@ void KWalletEntryList::itemDropped(QDropEvent *e, QListViewItem *item) {
 		delete ds;
 		//delete source if we were moving, i.e., we are dragging
 		//from kwalletmanager and Control is not pressed
-		if (ok && el && !(state & Qt::ControlButton) && sel) {
+		if (ok && el && !(state & Qt::ControlModifier) && sel) {
 			KWalletFolderItem *fi = dynamic_cast<KWalletFolderItem *>(sel);
 			if (fi) {
 				el->_wallet->removeFolder(fi->name());
@@ -517,7 +537,7 @@ void KWalletEntryList::setWallet(KWallet::Wallet *w) {
 }
 
 bool KWalletEntryList::existsFolder(const QString& name) {
-	for (QListViewItem *vi = firstChild(); vi; vi = vi->nextSibling()) {
+	for (Q3ListViewItem *vi = firstChild(); vi; vi = vi->nextSibling()) {
 		KWalletFolderItem *fi = dynamic_cast<KWalletFolderItem *>(vi);
 		if (!fi) {
 			continue;
@@ -530,7 +550,7 @@ bool KWalletEntryList::existsFolder(const QString& name) {
 }
 
 void KWalletEntryList::contentsDropEvent(QDropEvent *e) {
-	QListViewItem *i = itemAt(contentsToViewport(e->pos()));
+	Q3ListViewItem *i = itemAt(contentsToViewport(e->pos()));
 	itemDropped(e, i);
 }
 
@@ -545,7 +565,7 @@ void KWalletEntryList::contentsDragEnterEvent(QDragEnterEvent *e) {
 }
 
 KWalletFolderItem* KWalletEntryList::getFolder(const QString& name) {
-	for (QListViewItem *vi = firstChild(); vi; vi = vi->nextSibling()) {
+	for (Q3ListViewItem *vi = firstChild(); vi; vi = vi->nextSibling()) {
 		KWalletFolderItem *fi = dynamic_cast<KWalletFolderItem *>(vi);
 		if (!fi) {
 			continue;
@@ -557,7 +577,7 @@ KWalletFolderItem* KWalletEntryList::getFolder(const QString& name) {
 	return 0;
 }
 
-KWalletFolderItem *KWalletEntryList::getItemFolder(QListViewItem *item) {
+KWalletFolderItem *KWalletEntryList::getItemFolder(Q3ListViewItem *item) {
 	switch (item->rtti()) {
 		case KWalletFolderItemClass:
 			return dynamic_cast<KWalletFolderItem *>(item);
@@ -572,10 +592,10 @@ KWalletFolderItem *KWalletEntryList::getItemFolder(QListViewItem *item) {
 /****************
  *  KWalletIconDrag - Stores the data for wallet drags
  */
-class KWalletIconDrag : public QIconDrag {
+class KWalletIconDrag : public Q3IconDrag {
 	public:
 		KWalletIconDrag(QWidget *dragSource, const char *name = 0L)
-			: QIconDrag(dragSource, name) {
+			: Q3IconDrag(dragSource, name) {
 		}
 
 		virtual ~KWalletIconDrag() {}
@@ -591,11 +611,11 @@ class KWalletIconDrag : public QIconDrag {
 
 		QByteArray encodedData(const char *mime) const {
 			QByteArray a;
-			QCString mimetype(mime);
+			QByteArray mimetype(mime);
 			if (mimetype == "application/x-qiconlist") {
-				return QIconDrag::encodedData(mime);
+				return Q3IconDrag::encodedData(mime);
 			} else if (mimetype == "text/uri-list") {
-				QCString s = _urls.join("\r\n").latin1();
+				QByteArray s = _urls.join("\r\n").toLatin1();
 				if (_urls.count() > 0) {
 					s.append("\r\n");
 				}
@@ -605,9 +625,9 @@ class KWalletIconDrag : public QIconDrag {
 			return a;
 		}
 
-		void append(const QIconDragItem &item, const QRect &pr,
+		void append(const Q3IconDragItem &item, const QRect &pr,
 				const QRect &tr, const QString &url) {
-			QIconDrag::append(item, pr, tr);
+			Q3IconDrag::append(item, pr, tr);
 			_urls.append(url);
 		}
 
@@ -619,15 +639,15 @@ class KWalletIconDrag : public QIconDrag {
 *  *  KWalletIconView - An iconview to store wallets
 *   */
 KWalletIconView::KWalletIconView(QWidget *parent, const char *name)
-: KIconView(parent, name) {
+: K3IconView(parent, name) {
 	KGlobal::dirs()->addResourceType("kwallet", "share/apps/kwallet");
-	connect(this, SIGNAL(dropped(QDropEvent*, const QValueList<QIconDragItem>&)), SLOT(slotDropped(QDropEvent*, const QValueList<QIconDragItem>&)));
+	connect(this, SIGNAL(dropped(QDropEvent*, const Q3ValueList<Q3IconDragItem>&)), SLOT(slotDropped(QDropEvent*, const Q3ValueList<Q3IconDragItem>&)));
 }
 
 KWalletIconView::~KWalletIconView() {
 }
 
-void KWalletIconView::slotDropped(QDropEvent *e, const QValueList<QIconDragItem>& /*lst*/) {
+void KWalletIconView::slotDropped(QDropEvent *e, const Q3ValueList<Q3IconDragItem>& /*lst*/) {
 	if (e->source() == viewport()) {
 		e->ignore();
 		return;
@@ -639,15 +659,20 @@ void KWalletIconView::slotDropped(QDropEvent *e, const QValueList<QIconDragItem>
 	}
 
 	QByteArray edata = e->encodedData("text/uri-list");
-	QCString urls = edata.data();
+	QByteArray urls = edata.data();
 
-	QStringList ul = QStringList::split("\r\n", urls);
+	if (urls.isEmpty()) {
+		e->ignore();
+		return;
+	}
+
+	QStringList ul = QString(urls).split("\r\n", QString::SkipEmptyParts);
 	if (ul.isEmpty() || ul.first().isEmpty()) {
 		e->ignore();
 		return;
 	}
 
-	KURL u(ul.first());
+	KUrl u(ul.first());
 
 	if (u.fileName().isEmpty()) {
 		e->ignore();
@@ -662,7 +687,7 @@ void KWalletIconView::slotDropped(QDropEvent *e, const QValueList<QIconDragItem>
 	}
 
 	// FIXME: verify that it is a real wallet file first
-	KIO::NetAccess::file_copy(u, KURL::fromPathOrURL(dest));
+	KIO::NetAccess::file_copy(u, KUrl::fromPathOrUrl(dest));
 	e->accept();
 }
 
@@ -671,18 +696,18 @@ void KWalletIconView::contentsMousePressEvent(QMouseEvent *e) {
 	if (!findItem(_mousePos)) {
 		clearSelection();
 	}
-	KIconView::contentsMousePressEvent( e );
+	K3IconView::contentsMousePressEvent( e );
 }
 
-QDragObject *KWalletIconView::dragObject() {
+Q3DragObject *KWalletIconView::dragObject() {
 	KWalletIconDrag* id = new KWalletIconDrag(viewport(), "KWallet Drag");
 	QString path = "file:" + KGlobal::dirs()->saveLocation("kwallet");
 	QPoint pos = _mousePos;
-	for (QIconViewItem *item = firstItem(); item; item = item->nextItem()) {
+	for (Q3IconViewItem *item = firstItem(); item; item = item->nextItem()) {
 		if (item->isSelected()) {
 			QString url = path + item->text() + ".kwl";
-			QIconDragItem idi;
-			idi.setData(url.local8Bit());
+			Q3IconDragItem idi;
+			idi.setData(url.toLocal8Bit());
 			id->append(idi,
 			QRect(item->pixmapRect(false).topLeft() - pos,
 			item->pixmapRect(false).size()),
@@ -698,21 +723,31 @@ QDragObject *KWalletIconView::dragObject() {
 	return id;
 }
 
-QDragObject *KWalletEntryList::dragObject() {
-	QListViewItem *i = currentItem();
+Q3DragObject *KWalletEntryList::dragObject() {
+	Q3ListViewItem *i = currentItem();
 
-	QStoredDrag *sd = 0L;  
+	Q3StoredDrag *sd = 0L;  
 
 	if (i->rtti() == KWalletEntryItemClass) {
 		KWalletEntryItem *ei = dynamic_cast<KWalletEntryItem*>(i);
 		if (!ei) {
 			return 0L;
 		}
+		KWalletContainerItem *ci = dynamic_cast<KWalletContainerItem*>(ei->parent());
+		if (!ci) {
+			return 0L;
+		}
 		sd = new KWalletEntryDrag(viewport(), "KWallet Entry Drag");
 		QByteArray a;
-		QDataStream ds(a, IO_WriteOnly);
+		QDataStream ds(&a, QIODevice::WriteOnly);
+
+		ds.setVersion(QDataStream::Qt_3_1);
 		ds << KWALLETENTRYMAGIC;
-		ds << *ei;
+		ds << ei->text(0);
+		ds << ci->type();
+		QByteArray value;
+		ei->_wallet->readEntry(i->text(0), value);
+		ds << value;
 		sd->setEncodedData(a);
 	} else if (i->rtti() == KWalletFolderItemClass) {
 		KWalletFolderItem *fi = dynamic_cast<KWalletFolderItem*>(i);
@@ -721,7 +756,9 @@ QDragObject *KWalletEntryList::dragObject() {
 		}
 		sd = new KWalletFolderDrag(viewport(), "KWallet Folder Drag");
 		QByteArray a;
-		QDataStream ds(a, IO_WriteOnly);
+		QDataStream ds(&a, QIODevice::WriteOnly);
+
+		ds.setVersion(QDataStream::Qt_3_1);
 
 		ds << KWALLETFOLDERMAGIC;
 		ds << *fi;
